@@ -1,28 +1,23 @@
 #!/usr/bin/python
-
 import os
 import sys
-from ctypes import * 
-import platform
+from ctypes import *
+from sys import platform
 
-# thisdir = os.path.dirname(os.path.abspath(__file__))
-# lib = cdll.LoadLibrary(thisdir + '/NoetherAD.so')
+if platform == "darwin":
+    thisdir = os.path.dirname(os.path.abspath(__file__))
+    lib = cdll.LoadLibrary(thisdir + '/libNoetherAutoDiff.dylib')
+else:
+    thisdir = os.path.dirname(os.path.abspath(__file__))
+    lib = cdll.LoadLibrary(thisdir + '/NoetherADPy.so')
 
-parent_dir = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
-bin_dir = parent_dir + os.sep + "bin"
-# sys.path.append(bin_dir)
-
-if 'Linux' in platform.system():
-    lib = cdll.LoadLibrary(bin_dir + os.sep + "NoetherAD.so")
-elif 'Darwin' in platform.system:
-    lib = cdll.LoadLibrary(bin_dir + os.sep + "libNoetherAutoDiff.dylib")
 
 
 def wrapper(lib, funcname, restype, argtypes):
-    """
-    A wrapper that rest the restype and argtypes of a C
-    function and returns the function.
-    """
+    '''
+        A wrapper that rest the restype and argtypes of a C
+        function and returns the function.
+        '''
     func = lib.__getattr__(funcname)
     func.restype = restype
     func.argtypes = argtypes
@@ -30,15 +25,9 @@ def wrapper(lib, funcname, restype, argtypes):
 
 
 class NoetherAutoDiff(Structure):
-    """
-    A class the mirrors the C++ NoetherAutoDiff calls
-    and provids an interface to the C++ library
-    """
 
     def __init__(self, input, mode, inits={}, seeds={}):
-        """
-        Constructor function
-        """
+
         # inputs
         self.input = input
         self.mode = mode
@@ -92,45 +81,24 @@ class NoetherAutoDiff(Structure):
 
     # Comparison operators
     def __eq__(self, other):
-        """
-        Overriding `==` operator for NoetherAutoDiff objects.
-        """
         return self.equal(self.noether, other.noether)
 
     def __ne__(self, other):
-        """
-        Overriding `1=` operator for NoetherAutoDiff objects.
-        """
         return self.notEqual(self.noether, other.noether)
 
     def __lt__(self, other):
-        """
-        Overriding `<` operator for NoetherAutoDiff objects.
-        """
         return self.lessThan(self.noether, other.noether)
 
     def __le__(self, other):
-        """
-        Overriding `<=` operator for NoetherAutoDiff objects.
-        """
         return self.lessThanOrEqaul(self.noether, other.noether)
 
     def __gt__(self, other):
-        """
-        Overriding `>` operator for NoetherAutoDiff objects.
-        """
         return self.greaterThan(self.noether, other.noether)
 
     def __ge__(self, other):
-        """
-        Overriding `>=` operator for NoetherAutoDiff objects.
-        """
         return self.greaterThanOrEqual(self.noether, other.noether)
 
     def print(self):
-        """
-        Pretty prints the details of the NoetherAutoDiff object
-        """
         print("Input function:")
         print("  f = {}".format(self.input))
 
@@ -149,15 +117,6 @@ class NoetherAutoDiff(Structure):
 class NoetherAutoDiff_Vector(Structure):
 
     def __init__(self, input, mode, inits=[], seeds=[]):
-        """
-        Constructor for the NoetherAutoDiff_Vector
-
-        Args:
-            input: a list of strings representing each equation
-            mode: 0 for forward mode and 1 for reverse mode
-            inits: a list of values for the variables
-            seeds: a list of variables for the directional derivatives
-        """
 
         # inputs
         self.input = input
@@ -178,9 +137,8 @@ class NoetherAutoDiff_Vector(Structure):
         seeds_arr[:] = seeds
 
         # Define the argtypes and restype of the C functions
-        self.createNoetherAD_Vector = wrapper(lib, 'createNoetherAD_Vector', c_void_p, 
-            [POINTER(c_char), c_int, POINTER(c_double), POINTER(c_double), c_int])
-
+        self.createNoetherAD_Vector = wrapper(lib, 'createNoetherAD_Vector', c_void_p, [POINTER(c_char),
+                                                                                        c_int, POINTER(c_double), POINTER(c_double), c_int])
         # POINTER(c_double), POINTER(c_double * self.size)])
         self.get_val_vector = wrapper(lib, 'get_val_vector', c_double, [c_void_p])
 
@@ -224,53 +182,28 @@ class NoetherAutoDiff_Vector(Structure):
             self.jacobian.append(self.get_jacobian_vector(self.noether, c_int(i)))
 
     def get_jacobian(self):
-        """
-        Returns the jacobian of the function
-        """
         return self.jacobian
 
     # Comparison operators
     def __eq__(self, other):
-        """
-        Overriding `==` operator for NoetherAutoDiff objects.
-        """
         return self.equal_Vector(self.noether, other.noether)
 
     def __ne__(self, other):
-        """
-        Overriding `!=` operator for NoetherAutoDiff objects.
-        """
         return self.notEqual_Vector(self.noether, other.noether)
 
     def __lt__(self, other):
-        """
-        Overriding `<` operator for NoetherAutoDiff objects.
-        """
         return self.lessThan_Vector(self.noether, other.noether)
 
     def __le__(self, other):
-        """
-        Overriding `<=` operator for NoetherAutoDiff objects.
-        """
         return self.lessThanOrEqaul_Vector(self.noether, other.noether)
 
     def __gt__(self, other):
-        """
-        Overriding `>` operator for NoetherAutoDiff objects.
-        """
         return self.greaterThan_Vector(self.noether, other.noether)
 
     def __ge__(self, other):
-        """
-        Overriding `>=` operator for NoetherAutoDiff objects.
-        """
         return self.greaterThanOrEqual_Vector(self.noether, other.noether)
 
     def print(self):
-        """
-        Pretty prints the function str, evaluated val
-        and the derivaties.
-        """
         print("Input function:")
         print("  f = {}".format(self.input))
 
@@ -287,22 +220,9 @@ class NoetherAutoDiff_Vector(Structure):
 
 
 class NoetherAD(Structure):
-    """
-    A class that mirrors the main custormer interfacing class
-    by the same name of the C++ library. It provides
-    the same methods and functionality.
-    """
 
-    def __init__(self, inputs, mode, inits, seeds=[]):
-        """
-        Constructor method for NoetherAD class.
+    def __init__(self, inputs, mode, inits=[], seeds=[]):
 
-        Args:
-            input: a list of strings representing each equation
-            mode: 0 for forward mode and 1 for reverse mode
-            inits: a list of values for the variables
-            seeds: a list of variables for the directional derivatives
-        """
         if (not inputs or not inits):
             # if inputs or inits are empty, exit
             print("No input equations or variable values provided.")
@@ -317,6 +237,7 @@ class NoetherAD(Structure):
         self.val = []
         self.jacobian = []
 
+
         for i in range(len(inputs)):
             py_noether = NoetherAutoDiff_Vector(inputs[i], mode, inits, seeds)
             self.py_objs.append(py_noether)
@@ -324,9 +245,6 @@ class NoetherAD(Structure):
             self.val.append(py_noether.val)
 
     def get_jacobian(self):
-        """
-        Returns the jacobian values of each function
-        """
         self.jacobian = []
         for obj in self.py_objs:
             self.jacobian.append(obj.get_jacobian())
@@ -334,10 +252,6 @@ class NoetherAD(Structure):
         return self.jacobian
         
     def print(self):
-        """
-        Pretty prints the function str, evaluated val
-        and the derivaties for each function.
-        """
         if len(self.inputs) == 1:
             self.py_objs[0].print()
         else:
@@ -347,9 +261,6 @@ class NoetherAD(Structure):
 
     # Comparison operators
     def __eq__(self, other):
-        """
-        Overriding `==` operator for NoetherAutoDiff objects.
-        """
         if (len(self.py_objs) != len(other.py_objs)):
             return False
 
@@ -366,15 +277,9 @@ class NoetherAD(Structure):
             return False
 
     def __ne__(self, other):
-        """
-        Overriding `!=` operator for NoetherAutoDiff objects.
-        """
         return not (self == other)
 
     def __lt__(self, other):
-        """
-        Overriding `<` operator for NoetherAutoDiff objects.
-        """
         if (len(self.py_objs) != len(other.py_objs)):
             return False 
 
@@ -386,9 +291,6 @@ class NoetherAD(Structure):
         return True
 
     def __le__(self, other):
-        """
-        Overriding `<=` operator for NoetherAutoDiff objects.
-        """
         if (len(self.py_objs) != len(other.py_objs)):
             return False
 
@@ -400,9 +302,6 @@ class NoetherAD(Structure):
         return True
 
     def __gt__(self, other):
-        """
-        Overriding `>` operator for NoetherAutoDiff objects.
-        """
         if (len(self.py_objs) != len(other.py_objs)):
             return False
 
@@ -414,9 +313,6 @@ class NoetherAD(Structure):
         return True
 
     def __ge__(self, other):
-        """
-        Overriding `>=` operator for NoetherAutoDiff objects.
-        """
         if (len(self.py_objs) != len(other.py_objs)):
             return False
 
@@ -426,3 +322,4 @@ class NoetherAD(Structure):
                     return False
 
         return True
+        
